@@ -179,22 +179,53 @@ class route(ranaModule):
       self.doRoute(fromLat, fromLon, toLat, toLon)
       self.set('needRedraw', True) # show the new route
 
-    elif(message == "route"): # simple route, from here to selected point
-      # disable the point selection guis
-      self.selectTwoPoints = False
-      self.selectOnePoint = False
-      toPos = self.get("selectedPos", None)
-      if(toPos):
-        toLat,toLon = [float(a) for a in toPos.split(",")]
+    elif(message == "route"): # find a route
+      if (type=='md'): # mesage-list based routing
+        if args:
+          type = args['type']
+          go = False
+          if type=='ll2ll':
+            (fromLat,fromLon) = (float(args['fromLat']),float(args['fromLon']))
+            (toLat,toLon) = (float(args['toLat']),float(args['toLon']))
+            go = True
+          elif type=='pos2ll':
+            pos = self.get('pos', None)
+            if pos:
+              (fromLat,fromLon) = pos
+              (toLat,toLon) = (float(args['toLat']),float(args['toLon']))
+              go = True
+          if go: # are ve GO for routing ?
+            print "Routing %f,%f to %f,%f" % (fromLat, fromLon, toLat, toLon)
+            try:
+              self.doRoute(fromLat, fromLon, toLat, toLon)
+            except:
+              self.sendMessage('ml:notification:m:No route found;3')
+            if "show" in args:
+              """switch to map view and go to start/destination, if requested"""
+              where = args['show']
+              if where == 'start':
+                (cLat, cLon) = (fromLat,fromLon)
+              elif where == "destination":
+                (cLat, cLon) = (toLat,toLon)
+              self.sendMessage('mapView:recentre %f %f|set:menu:None' % (cLat,cLon))
 
-        fromPos = self.get("pos", None)
-        if(fromPos):
-          (fromLat, fromLon) = fromPos
-          print "Routing %f,%f to %f,%f" % (fromLat, fromLon, toLat, toLon)
+            self.set('needRedraw', True) # show the new route
+      else: # simple route, from here to selected point
+        # disable the point selection guis
+        self.selectTwoPoints = False
+        self.selectOnePoint = False
+        toPos = self.get("selectedPos", None)
+        if(toPos):
+          toLat,toLon = [float(a) for a in toPos.split(",")]
 
-          # TODO: wait message (would it be needed when using internet routing ?)
-          self.doRoute(fromLat, fromLon, toLat, toLon)
-          self.set('needRedraw', True) # show the new route
+          fromPos = self.get("pos", None)
+          if(fromPos):
+            (fromLat, fromLon) = fromPos
+            print "Routing %f,%f to %f,%f" % (fromLat, fromLon, toLat, toLon)
+
+            # TODO: wait message (would it be needed when using internet routing ?)
+            self.doRoute(fromLat, fromLon, toLat, toLon)
+            self.set('needRedraw', True) # show the new route
 
     elif(message == 'storeRoute'):
       loadTracklogs = self.m.get('loadTracklogs', None)
@@ -265,12 +296,6 @@ class route(ranaModule):
           self.doRoute(pLat, pLon, dLat, dLon)
 
 
-
-
-
-
-      
-
   def doRoute(self, fromLat, fromLon, toLat, toLon):
     """Route from one point to another, and set that as the active route"""
     online = self.m.get('onlineServices', None)
@@ -434,7 +459,10 @@ class route(ranaModule):
         clickHandler.registerXYWH(x, y, x+w, y+h, 'route:setEnd')
 
   def drawScreenOverlay(self, cr):
-    if self.selectTwoPoints == True:
+    if self.route: # current route info button
+      self.drawCurrentRouteInfoButton(cr)
+
+    if self.selectTwoPoints == True: # poin selection menu
       self.drawTwoPointsMenu(cr)
 
   def drawMapOverlay(self, cr):
@@ -635,6 +663,20 @@ class route(ranaModule):
 
     return array
 
+  def drawCurrentRouteInfoButton(self,cr):
+    (x,y,w,h) = self.get('viewport')
+    menus = self.m.get('menu', None)
+    dx = min(w,h) / 5.0
+    dy = dx
+    x1 = (x+w)-dx
+    y1 = (y-dy)+h
+    if self.selectTwoPoints:
+      """move to avoid colision with the point selection menu"""
+      x1 = x1-dx
+      y1 = y1-dy
+    menus.drawButton(cr, x1, y1, dx, dy, 'info#route', "generic_alpha", 'set:menu:currentRouteBackToMap')
+    
+
   def drawTwoPointsMenu(self, cr):
     (x,y,w,h) = self.get('viewport')
     dx = min(w,h) / 5.0
@@ -658,9 +700,6 @@ class route(ranaModule):
     menus.drawButton(cr, x1, y1-dy, dx, dy, 'end', endIcon, "route:expectEnd")
     menus.drawButton(cr, x1, y1, dx, dy, 'route', "generic_alpha", routingAction)
 
-    if self.route:
-      menus.drawButton(cr, x1-dy, y1-dx, dx, dy, 'info#route', "generic_alpha", 'set:menu:currentRouteBackToMap')
-
     # "flush" cairo operations
     cr.stroke()
     cr.fill()
@@ -734,9 +773,9 @@ class route(ranaModule):
 
       # if called from the osd menu, go back to map at escape
       if menuName == 'currentRouteBackToMap':
-        parent = 'None'
+        parent = 'set:menu:None'
       else:
-        parent = 'route'
+        parent = 'set:menu:route'
 
       if self.route == []:
         action = "set:menu:None"
@@ -756,28 +795,24 @@ class route(ranaModule):
         distance = units.m2CurrentUnitString(float(dir['Directions']['Distance']['meters']))
         steps = len(dir['Directions']['Routes'][0]['Steps']) # number of steps
 
-#        for step in dir['Directions']['Routes'][0]['Steps']:
-#          print step
-
-
         start = ""
         startAddress = self.start[2]
         (lat1,lon1) = (self.start[0],self.start[1])
         for item in startAddress.split(','):
-          start += "|%s" % item
-    #    start += "|(%f,%f)" % (lat1,lon1)
+          start += "\n%s" % item
+    #    start += "\n(%f,%f)" % (lat1,lon1)
 
         destination = ""
         destinationAddress = self.destination[2]
         (lat2,lon2) = (self.destination[0],self.destination[1])
         for item in destinationAddress.split(','):
-          destination += "|%s" % item
-    #    destination += "|(%f,%f)" % (lat2,lon2)
+          destination += "\n%s" % item
+    #    destination += "\n(%f,%f)" % (lat2,lon2)
 
         text = "%s" % start
-        text+= "|%s" % destination
-        text+= "||%s in about %s and %s steps" % (distance, duration, steps)
-        text+= "|(%f,%f)->(%f,%f)" % (lat1,lon1,lat2,lon2)
+        text+= "\n%s" % destination
+        text+= "\n\n%s in about %s and %s steps" % (distance, duration, steps)
+        text+= "\n(%f,%f)->(%f,%f)" % (lat1,lon1,lat2,lon2)
 
         self.text = text
       else:
@@ -788,9 +823,6 @@ class route(ranaModule):
       if self.once:
         self.once = False
 
-#        entry = self.m.get('textEntry', None)
-#        entry.entryBox("Enter destination")
-
       box = (text , "set:menu:currentRoute")
       menus.drawThreePlusOneMenu(cr, menuName, parent, button1, button2, box)
       menus.clearMenu('currentRouteTools', "set:menu:currentRoute")
@@ -806,6 +838,7 @@ class route(ranaModule):
         else:
           menus.addItem('currentRouteTools', 'navigation#start', 'generic', 'set:menu:routeSelectFirstStep')
 
+      menus.addItem('currentRouteTools', 'clear', 'generic', 'route:clear|set:menu:None')
 
 
 
@@ -817,13 +850,6 @@ class route(ranaModule):
         return
 
 
-#      print self.get('textEntry', "")
-#      print self.get('textEntryDone', "")
-#      print self.expectTextEntry
-#      print self.startAddress
-#      print self.destinationAddress
-
-
       (e1,e2,e3,e4,alloc) = menus.threePlusOneMenuCoords()
       (x1,y1) = e1
       (x2,y2) = e2
