@@ -201,6 +201,16 @@ class search(ranaModule):
         entryText = ""
         entry.entryBox(self, 'customQuery','Enter your search query',entryText)
 
+    elif message == "routeToActiveResult":
+      """get a route from current position to active search result
+         * center on the current position
+         -> we want to actually got to there :)"""
+      activeResultTupple = self.getActiveResultTupple()
+      activeResult = activeResultTupple[1]
+      lat = float(activeResult['lat'])
+      lon = float(activeResult['lng'])
+      self.sendMessage('md:route:route:type=pos2ll;toLat=%f;toLon=%f;show=start' % (lat,lon) )
+
     self.set("needRedraw", True)
 
 
@@ -279,12 +289,21 @@ class search(ranaModule):
          which is created from the initial ordering
          without this,(with distance sort) we would get different results for a key, if we moved fast enoght :)
       """
-      result = filter(lambda x: x[2] == resultNumber, list).pop() # get the result for the ABSOLUTE key
+      result = self.getResult(resultNumber, list)
       self.drawGLSResultMenu(cr, result)
 
     elif menuName == 'searchCustomQuery':
       self.drawSearchCustomQueryMenu(cr)
 
+  def getActiveResultTupple(self):
+    resultNumber = int(self.get('searchResultsItemNr', 0))
+    return self.getResult(resultNumber)
+
+  def getResult(self, resultNumber, list=None):
+    if list == None:
+      list = self.updateDistance()
+    return filter(lambda x: x[2] == resultNumber, list).pop() # get the result for the ABSOLUTE key
+
   def describeItem(self, index, category, list):
 #    longName = name = item.getTracklogName()
 #    print filter(lambda x: x.getTracklogName() == longName, loadedTracklogs)
@@ -355,8 +374,7 @@ class search(ranaModule):
 
   def drawGLSResultMenu(self, cr, resultTupple):
     """draw an info screen for a Google local search result"""
-
-
+    
     # get coordinate allocation for the menu elements
     menus = self.m.get("menu",None)
     (e1,e2,e3,e4,alloc) = menus.threePlusOneMenuCoords()
@@ -386,25 +404,24 @@ class search(ranaModule):
     menus.drawButton(cr, x4, y4, w4, h4, "", "generic", "set:menu:None")
 
     # * draw details from the search result
-    text = "%s (%s)" % (result['titleNoFormatting'],distanceString)
+    text = "\n%s (%s)" % (result['titleNoFormatting'],distanceString)
 
     try: # the adress can be unknown
-#      print result['addressLines']
       for addressLine in result['addressLines']:
-        text += "|%s" % addressLine
+        text += "\n%s" % addressLine
     except:
-      text += "|%s" % "no adress found"
+      text += "\n%s" % "no adress found"
 
     try: # it seems, that this entry is no guarantied
       for phoneNumber in result['phoneNumbers']:
         type = ""
         if phoneNumber['type'] != "":
           type = " (%s)" % phoneNumber['type']
-        text += "|%s%s" % (phoneNumber['number'], type)
+        text += "\n%s%s" % (phoneNumber['number'], type)
     except:
-      text += "|%s" % "no phone numbers found"
+      text += "\n%s" % "no phone numbers found"
 
-    text += "|coordinates: %f, %f" % (lat,lon)
+    text += "\ncoordinates: %f, %f" % (lat,lon)
 
     menus.drawTextToSquare(cr, x4, y4, w4, h4, text) # display the text in the box
 
@@ -530,8 +547,9 @@ class search(ranaModule):
 
       # setup the searchResultTools submenu
       m.clearMenu('searchResultTools', 'set:menu:searchResultsItem')
+      m.addItem('searchResultTools', "here#route", "generic", "search:routeToActiveResult")
+      m.addItem('searchResultTools', "add to POI", "generic", "search:reset|search:storePOI")
       m.addItem('searchResultTools', "results#clear", 'generic', 'search:clearSearch|set:menu:None')
-      m.addItem('searchResultTools', "add to POI", "generic", "search:reset|search:storePOI|set:menu:searchResults")
     # TODO: add "find route to"
 
   def handleTextEntryResult(self, key, result):
